@@ -331,6 +331,7 @@ func pagerFromArgs(
 
 	noLineNumbers := flagSet.Bool("no-linenumbers", noLineNumbersDefault(), "Hide line numbers on startup, press left arrow key to show")
 	noStatusBar := flagSet.Bool("no-statusbar", false, "Hide the status bar, toggle with '='")
+	noReFormat := flagSet.Bool("no-reformat", false, "Never reformat the input (but keep highlighting)")
 	quitIfOneScreen := flagSet.Bool("quit-if-one-screen", false, "Don't page if contents fits on one screen")
 	noClearOnExit := flagSet.Bool("no-clear-on-exit", false, "Retain screen contents when exiting moar")
 	statusBarStyle := flagSetFunc(flagSet, "statusbar", m.STATUSBAR_STYLE_INVERSE,
@@ -460,15 +461,16 @@ func pagerFromArgs(
 	}
 
 	var reader *m.Reader
+	shouldFormat := !*noReFormat
 	if stdinIsRedirected {
 		// Display input pipe contents
-		reader = m.NewReaderFromStreamWithoutStyle("", os.Stdin, formatter, *lexer)
+		reader = m.NewReaderFromStream("", os.Stdin, formatter, m.ReaderOptions{Lexer: *lexer, ShouldFormat: shouldFormat})
 	} else {
 		// Display the input file contents
 		if len(flagSet.Args()) != 1 {
 			panic("Invariant broken: Expected exactly one filename")
 		}
-		reader, err = m.NewReaderFromFilenameWithoutStyle(flagSet.Args()[0], formatter, *lexer)
+		reader, err = m.NewReaderFromFilename(flagSet.Args()[0], formatter, m.ReaderOptions{Lexer: *lexer, ShouldFormat: shouldFormat})
 		if err != nil {
 			return nil, nil, chroma.Style{}, nil, err
 		}
